'`matflow_formable.load.py`'

import numpy as np
from formable import load_cases

from matflow_formable import (
    input_mapper,
    output_mapper,
    cli_format_mapper,
    register_output_file,
    func_mapper,
)


@func_mapper(task='generate_load_case', method='uniaxial')
def get_uniaxial_load_cases(total_times, num_increments, directions,
                            target_strain_rates=None, target_strains=None,
                            rotations=None, dump_frequency=1):

    if target_strains is None:
        target_strains = [None] * len(total_times)
    elif target_strain_rates is None:
        target_strain_rates = [None] * len(total_times)

    if rotations is None:
        rotations = [None] * len(total_times)

    all_load_cases = []
    for t, n, eps_dot, eps, d, rot in zip(
        total_times,
        num_increments,
        target_strain_rates,
        target_strains,
        directions,
        rotations,
    ):
        all_load_cases.append(
            load_cases.get_load_case_uniaxial(
                total_time=t,
                num_increments=n,
                direction=d,
                target_strain_rate=eps_dot,
                target_strain=eps,
                rotation=rot,
                dump_frequency=dump_frequency,
            )
        )

    out = {'load_case': all_load_cases}

    return out


@func_mapper(task='generate_load_case', method='biaxial')
def get_biaxial_load_cases(total_times, num_increments, directions,
                           target_strain_rates=None, target_strains=None,
                           dump_frequency=1):

    if target_strains is None:
        target_strains = [None] * len(total_times)
    elif target_strain_rates is None:
        target_strain_rates = [None] * len(total_times)

    print(f'target_strains: {target_strains}')
    print(f'target_strain_rates: {target_strain_rates}')

    all_load_cases = []
    for t, n, eps_dot, eps, d in zip(
        total_times,
        num_increments,
        target_strain_rates,
        target_strains,
        directions,
    ):
        all_load_cases.append(
            load_cases.get_load_case_biaxial(
                total_time=t,
                num_increments=n,
                direction=d,
                target_strain_rate=eps_dot,
                target_strain=eps,
                dump_frequency=dump_frequency,
            )
        )

    out = {
        'load_case': all_load_cases,
    }
    return out


@func_mapper(task='generate_load_case', method='plane_strain')
def get_plane_strain_load_cases(total_times, num_increments, directions,
                                target_strain_rates=None, target_strains=None,
                                dump_frequency=1):

    if target_strains is None:
        target_strains = [None] * len(total_times)
    elif target_strain_rates is None:
        target_strain_rates = [None] * len(total_times)

    all_load_cases = []
    for t, n, eps_dot, eps, d in zip(
        total_times,
        num_increments,
        target_strain_rates,
        target_strains,
        directions,
    ):
        all_load_cases.append(
            load_cases.get_load_case_plane_strain(
                total_time=t,
                num_increments=n,
                direction=d,
                target_strain_rate=eps_dot,
                target_strain=eps,
                dump_frequency=dump_frequency,
            )
        )

    out = {
        'load_case': all_load_cases,
    }
    return out


@func_mapper(task='generate_load_case', method='random_2D')
def get_random_2D_load_cases(total_times, num_increments, normal_directions,
                             target_strain_rates=None, target_strains=None,
                             dump_frequency=1):

    if target_strains is None:
        target_strains = [None] * len(total_times)
    elif target_strain_rates is None:
        target_strain_rates = [None] * len(total_times)

    all_load_cases = []
    for t, n, eps_dot, eps, nd in zip(
        total_times,
        num_increments,
        target_strain_rates,
        target_strains,
        normal_directions,
    ):
        all_load_cases.append(
            load_cases.get_load_case_random_2D(
                total_time=t,
                num_increments=n,
                normal_direction=nd,
                target_strain_rate=eps_dot,
                target_strain=eps,
                dump_frequency=dump_frequency,
            )
        )

    out = {
        'load_case': all_load_cases,
    }
    return out


@func_mapper(task='generate_load_case', method='random_3D')
def get_random_3D_load_cases(total_times, num_increments, target_strains, rotation=True,
                             rotation_max_angle=10, rotation_load_case=True,
                             non_random_rotation=None, dump_frequency=1):

    if non_random_rotation is None:
        non_random_rotation = [None] * len(total_times)

    all_load_cases = []
    for t, n, eps, rot in zip(
        total_times,
        num_increments,
        target_strains,
        non_random_rotation
    ):
        all_load_cases.append(
            load_cases.get_load_case_random_3D(
                total_time=t,
                num_increments=n,
                target_strain=eps,
                rotation=rotation,
                rotation_max_angle=rotation_max_angle,
                rotation_load_case=rotation_load_case,
                non_random_rotation=rot,
                dump_frequency=dump_frequency,
            )
        )

    out = {
        'load_case': all_load_cases,
    }
    return out



'`matflow_formable.__init__.py`'

from functools import partial

from matflow_formable._version import __version__

from matflow.extensions import (
    input_mapper,
    output_mapper,
    cli_format_mapper,
    register_output_file,
    func_mapper,
    software_versions
)

SOFTWARE = 'formable'

input_mapper = partial(input_mapper, software=SOFTWARE)
output_mapper = partial(output_mapper, software=SOFTWARE)
cli_format_mapper = partial(cli_format_mapper, software=SOFTWARE)
register_output_file = partial(register_output_file, software=SOFTWARE)
func_mapper = partial(func_mapper, software=SOFTWARE)
software_versions = partial(software_versions, software=SOFTWARE)

# This import must come after assigning the partial functions:
from matflow_formable import main
from matflow_formable import load


'`matflow_formable.main.py`'

from matflow_formable import (
    input_mapper,
    output_mapper,
    cli_format_mapper,
    register_output_file,
    func_mapper,
    software_versions,
)

from formable import __version__ as formable_version
from formable.load_response import LoadResponse, LoadResponseSet


@func_mapper(task='fit_yield_function', method='formable')
def fit_yield_function(yield_function_name, yield_point_criteria, uniaxial_response,
                       multiaxial_responses):

    # Generate LoadResponse objects:
    uni_resp = LoadResponse(
        true_stress=uniaxial_response['vol_avg_stress'],
        equivalent_plastic_strain=uniaxial_response['vol_avg_equivalent_plastic_strain'],
    )
    multi_resp = []
    for resp_dat in multiaxial_responses:
        multi_resp.append(
            LoadResponse(
                true_stress=resp_dat['vol_avg_stress'],
                equivalent_plastic_strain=resp_dat['vol_avg_equivalent_plastic_strain'],
            )
        )
    response_set = LoadResponseSet(multi_resp)
    response_set.calculate_yield_stresses(yield_point_criteria)
    response_set.fit_yield_function(yield_function_name, uniaxial_response=uni_resp)
    out = {
        'fitted_yield_functions': [
            {
                'name': yield_function_name,
                **i['yield_function'].get_parameters()
            }
            for i in response_set.yield_functions
        ]
    }

    return out


@software_versions()
def get_versions():
    return {'formable (Python)': {'version': formable_version}}
